@@ -27,7 +27,7 @@ def Leave(GroupID):
 
 def GetFunds(GroupID):
     try:
-        response = Internal.CurrentCookie.post(f"{Utils.EconomyURL}/groups/{GroupID}/currency/")
+        response = Internal.CurrentCookie.get(f"{Utils.EconomyURL}/groups/{GroupID}/currency/")
         return response.json()['robux']
     except:
         return response.json()
@@ -102,5 +102,3 @@ def ChangeRank(GroupID,targetUserID,RoleID):
 
 
 
-
-
